@@ -14,22 +14,28 @@ Created on 13 Sep 2020
 :copyright: SEMU Consulting © 2020
 :license: BSD 3-Clause
 """
-# pylint: disable=invalid-name, too-many-instance-attributes, too-many-ancestors
+# pylint: disable=invalid-name
 
 from io import BytesIO
 from time import time
 from tkinter import Frame, Canvas, font, NW, N, S, E, W
-
+from http.client import responses
 from PIL import ImageTk, Image
-import requests
+from requests import get, RequestException, ConnectionError as ConnError, ConnectTimeout
 
-from .globals import WIDGETU2, MAPURL, MAP_UPDATE_INTERVAL, IMG_WORLD, ICON_POS, BGCOL
-from .strings import (
-    NOWEBMAPERROR1,
-    NOWEBMAPERROR2,
-    NOWEBMAPERROR3,
-    NOWEBMAPERROR4,
-    NOWEBMAPERROR5,
+from pygpsclient.globals import (
+    WIDGETU2,
+    MAPURL,
+    MAP_UPDATE_INTERVAL,
+    IMG_WORLD,
+    ICON_POS,
+    BGCOL,
+)
+from pygpsclient.strings import (
+    NOWEBMAPFIX,
+    NOWEBMAPCONN,
+    NOWEBMAPHTTP,
+    NOWEBMAPKEY,
 )
 
 
@@ -82,9 +88,6 @@ class MapviewFrame(Frame):
         :param str fix (kwarg): fix type as string
         """
 
-        w, h = self.width, self.height
-        resize_font = font.Font(size=min(int(w / 20), 14))
-
         if self.__app.frm_settings.webmap:
             static = False
         else:
@@ -102,22 +105,8 @@ class MapviewFrame(Frame):
                 "TIME ONLY",
             )
         ):
-            self.can_mapview.delete("all")
             self.reset_map_refresh()
-            self.can_mapview.create_text(
-                w / 2,
-                h / 2 - (w / 20),
-                text=NOWEBMAPERROR1,
-                fill="red",
-                font=resize_font,
-            )
-            self.can_mapview.create_text(
-                w / 2,
-                h / 2 + (w / 20),
-                text=NOWEBMAPERROR5,
-                fill="red",
-                font=resize_font,
-            )
+            self._disp_error(NOWEBMAPFIX)
             return
 
         if static:
@@ -158,27 +147,12 @@ class MapviewFrame(Frame):
         :param float hacc: horizontal accuracy
         """
 
-        w, h = self.width, self.height
-        resize_font = font.Font(size=min(int(w / 20), 14))
+        sc = "NO CONNECTION"
+        msg = ""
 
         apikey = self.__app.api_key
         if apikey == "":
-            self.can_mapview.delete("all")
-            self.reset_map_refresh()
-            self.can_mapview.create_text(
-                w / 2,
-                h / 2 - (w / 20),
-                text=NOWEBMAPERROR1,
-                fill="orange",
-                font=resize_font,
-            )
-            self.can_mapview.create_text(
-                w / 2,
-                h / 2 + (w / 20),
-                text=NOWEBMAPERROR2,
-                fill="orange",
-                font=resize_font,
-            )
+            self._disp_error(NOWEBMAPKEY)
             return
 
         now = time()
@@ -192,29 +166,22 @@ class MapviewFrame(Frame):
         url = self._format_url(apikey, lat, lon, hacc)
 
         try:
-            response = requests.get(url)
-            if response.status_code == 200:
+            response = get(url)
+            sc = responses[response.status_code]  # get descriptive HTTP status
+            response.raise_for_status()  # raise Exception on HTTP error
+            if sc == "OK":
                 img_data = response.content
                 self._img = ImageTk.PhotoImage(Image.open(BytesIO(img_data)))
                 self.can_mapview.delete("all")
                 self.can_mapview.create_image(0, 0, image=self._img, anchor=NW)
                 self.can_mapview.update()
-        except Exception:  # pylint: disable=broad-except
-            self.can_mapview.delete("all")
-            self.can_mapview.create_text(
-                w / 2,
-                h / 2 - (w / 20),
-                text=NOWEBMAPERROR3,
-                fill="red",
-                font=resize_font,
-            )
-            self.can_mapview.create_text(
-                w / 2,
-                h / 2 + (w / 20),
-                text=NOWEBMAPERROR4,
-                fill="red",
-                font=resize_font,
-            )
+                return
+        except (ConnError, ConnectTimeout):
+            msg = NOWEBMAPCONN
+        except RequestException:
+            msg = NOWEBMAPHTTP.format(sc)
+
+        self._disp_error(msg)
 
     def _draw_countdown(self, wait):
         """
@@ -248,6 +215,25 @@ class MapviewFrame(Frame):
             apikey, lat, lon, self.__app.frm_settings.mapzoom, radius, lat, lon, w, h
         )
 
+    def _disp_error(self, msg):
+        """
+        Display error message in webmap widget.
+
+        :param str msg: error message
+        """
+
+        w, h = self.width, self.height
+        resize_font = font.Font(size=min(int(w / 20), 14))
+
+        self.can_mapview.delete("all")
+        self.can_mapview.create_text(
+            w / 2,
+            h / 2 - (w / 20),
+            text=msg,
+            fill="orange",
+            font=resize_font,
+        )
+
     def reset_map_refresh(self):
         """
         Reset map refresh counter to zero
