@@ -11,19 +11,24 @@ Created on 16 Sep 2020
 :license: BSD 3-Clause
 """
 
+import logging
 from io import BufferedReader
 from threading import Thread
 from serial import Serial, SerialException, SerialTimeoutException
-from pyubx2 import UBXReader, UBXParseError, protocol
-from pynmeagps import NMEAParseError
+from pynmeagps import NMEAReader, NMEAParseError
+from pyrtcm import RTCMReader, RTCMParseError
+from pyubx2 import UBXReader, UBXParseError, RTCMMessage as RTCMStub, protocol
 import pyubx2.ubxtypes_core as ubt
 from pygpsclient.globals import (
     CONNECTED,
     CONNECTED_FILE,
     DISCONNECTED,
-    QUITONERRORDEFAULT,
+    CRLF,
+    USE_PYRTCM,
 )
-from pygpsclient.strings import NOTCONN, SEROPENERROR, FILEOPENERROR, ENDOFFILE
+from pygpsclient.strings import NOTCONN, SEROPENERROR, ENDOFFILE
+
+LOGGING = logging.WARNING
 
 
 class SerialHandler:
@@ -47,9 +52,13 @@ class SerialHandler:
         self._serial_thread = None
         self._file_thread = None
         self._connected = False
-        self._reader = None
         self._reading = False
 
+        logging.basicConfig(
+            format="%(asctime)-15s [%(levelname)s] %(funcName)s: %(message)s",
+            level=LOGGING,
+        )
+
     def __del__(self):
         """
         Destructor.
@@ -64,13 +73,13 @@ class SerialHandler:
         """
         Open serial connection.
         """
+        # pylint: disable=consider-using-with
 
         serial_settings = self.__app.frm_settings.serial_settings()
         if serial_settings.status == 3:  # NOPORTS
             return
 
         try:
-
             self._serial_object = Serial(
                 serial_settings.port,
                 serial_settings.bpsrate,
@@ -82,11 +91,24 @@ class SerialHandler:
                 timeout=serial_settings.timeout,
             )
             self._serial_buffer = BufferedReader(self._serial_object)
-            msg = (
-                f"{serial_settings.port}:{serial_settings.port_desc}"
-                + f"@ {str(serial_settings.bpsrate)}"
+            self.__app.frm_banner.update_conn_status(CONNECTED)
+            self.__app.set_connection(
+                (
+                    f"{serial_settings.port}:{serial_settings.port_desc} "
+                    + f"@ {str(serial_settings.bpsrate)}"
+                ),
+                "green",
             )
-            self.connect_stream(self._serial_buffer, CONNECTED, msg)
+            self.__app.frm_settings.enable_controls(CONNECTED)
+            self._connected = True
+            self.start_read_thread()
+
+            if self.__app.frm_settings.datalogging:
+                self.__app.file_handler.open_logfile()
+
+            if self.__app.frm_settings.record_track:
+                self.__app.file_handler.open_trackfile()
+            self.__app.set_status("Connected", "blue")
 
         except (IOError, SerialException, SerialTimeoutException) as err:
             self._connected = False
@@ -105,53 +127,34 @@ class SerialHandler:
         """
         Open binary data file connection.
         """
+        # pylint: disable=consider-using-with
 
         in_filepath = self.__app.frm_settings.infilepath
         if in_filepath is None:
             return
 
         try:
-
             self._serial_object = open(in_filepath, "rb")
             self._serial_buffer = BufferedReader(self._serial_object)
-            msg = f"{in_filepath}"
-            self.connect_stream(self._serial_buffer, CONNECTED_FILE, msg)
+            self.__app.frm_banner.update_conn_status(CONNECTED_FILE)
+            self.__app.set_connection(f"{in_filepath}", "blue")
+            self.__app.frm_settings.enable_controls(CONNECTED_FILE)
+            self._connected = True
+            self.start_readfile_thread()
+
+            if self.__app.frm_settings.datalogging:
+                self.__app.file_handler.open_logfile()
+
+            if self.__app.frm_settings.record_track:
+                self.__app.file_handler.open_trackfile()
 
         except (IOError, SerialException, SerialTimeoutException) as err:
             self._connected = False
             self.__app.set_connection(f"{in_filepath}", "red")
-            self.__app.set_status(FILEOPENERROR.format(err), "red")
+            self.__app.set_status(SEROPENERROR.format(err), "red")
             self.__app.frm_banner.update_conn_status(DISCONNECTED)
             self.__app.frm_settings.enable_controls(DISCONNECTED)
 
-    def connect_stream(self, stream: object, status: int, msg: str):
-        """
-        Instantiate UBXReader object and start the relevant
-        serial or file reader thread.
-
-        :param object stream: serial or file stream
-        :param str status: serial or file
-        :param str msg: connection descriptor message
-        """
-
-        self._reader = UBXReader(stream, quitonerror=QUITONERRORDEFAULT)
-
-        if self.__app.frm_settings.datalogging:
-            self.__app.file_handler.open_logfile()
-
-        if self.__app.frm_settings.record_track:
-            self.__app.file_handler.open_trackfile()
-
-        self.__app.set_status("Connected", "blue")
-        self.__app.frm_banner.update_conn_status(status)
-        self.__app.frm_settings.enable_controls(status)
-        self.__app.set_connection(msg, "green")
-        self._connected = True
-        if status == CONNECTED:  # serial
-            self.start_read_thread()
-        else:  # file
-            self.start_readfile_thread()
-
     def disconnect(self):
         """
         Close serial connection.
@@ -160,7 +163,6 @@ class SerialHandler:
         if self._connected:
             try:
                 self._reading = False
-                self._reader = None
                 self._serial_object.close()
                 self.__app.frm_banner.update_conn_status(DISCONNECTED)
                 self.__app.set_connection(NOTCONN, "red")
@@ -179,56 +181,41 @@ class SerialHandler:
         self.__app.frm_settings.enable_controls(self._connected)
 
     @property
-    def port(self) -> str:
+    def port(self):
         """
         Getter for port
-
-        :return: port descriptor
-        :rtype: str
         """
 
         return self.__app.frm_settings.serial_settings().port
 
     @property
-    def connected(self) -> int:
+    def connected(self):
         """
         Getter for connection status
-
-        :return: connection status flag
-        :rtype: int
         """
 
         return self._connected
 
     @property
-    def serial(self) -> object:
+    def serial(self):
         """
         Getter for serial object
-
-        :return: serial object
-        :rtype: object
         """
 
         return self._serial_object
 
     @property
-    def buffer(self) -> object:
+    def buffer(self):
         """
         Getter for serial buffer
-
-        :return: serial buffer object
-        :rtype: object
         """
 
         return self._serial_buffer
 
     @property
-    def thread(self) -> object:
+    def thread(self):
         """
         Getter for serial thread
-
-        :return: serial reader thread
-        :rtype: object
         """
 
         return self._serial_thread
@@ -253,7 +240,7 @@ class SerialHandler:
         if self._connected:
             self._reading = True
             self.__app.frm_mapview.reset_map_refresh()
-            self._serial_thread = Thread(target=self._read_thread(), daemon=True)
+            self._serial_thread = Thread(target=self._read_thread, daemon=True)
             self._serial_thread.start()
 
     def start_readfile_thread(self):
@@ -264,7 +251,7 @@ class SerialHandler:
         if self._connected:
             self._reading = True
             self.__app.frm_mapview.reset_map_refresh()
-            self._file_thread = Thread(target=self._readfile_thread(), daemon=True)
+            self._file_thread = Thread(target=self._readfile_thread, daemon=True)
             self._file_thread.start()
 
     def stop_read_thread(self):
@@ -275,6 +262,7 @@ class SerialHandler:
         if self._serial_thread is not None:
             self._reading = False
             self._serial_thread = None
+            # self.__app.set_status(STOPDATA, "red")
 
     def stop_readfile_thread(self):
         """
@@ -284,6 +272,7 @@ class SerialHandler:
         if self._file_thread is not None:
             self._reading = False
             self._file_thread = None
+            # self.__app.set_status(STOPDATA, "red")
 
     def _read_thread(self):
         """
@@ -321,7 +310,7 @@ class SerialHandler:
 
         if self._reading and self._serial_object is not None:
             try:
-                self._parse_data()
+                self._parse_data(self._serial_buffer)
             except SerialException as err:
                 self.__app.set_status(f"Error {err}", "red")
 
@@ -335,21 +324,70 @@ class SerialHandler:
         self.disconnect()
         self.__app.set_status(ENDOFFILE, "blue")
 
-    def _parse_data(self):
+    def _parse_data(self, stream: object):
         """
-        Invoke the UBXReader.read() method to read and parse the data stream
-        and direct to the appropriate UBX and/or NMEA protocol handler,
-        depending on which protocols are filtered.
+        Read the binary data and direct to the appropriate
+        UBX and/or NMEA protocol handler, depending on which protocols
+        are filtered.
+
+        :param Serial ser: serial port
         """
 
+        parsing = True
         raw_data = None
         parsed_data = None
         protfilter = self.__app.frm_settings.protocol
 
         try:
-            (raw_data, parsed_data) = self._reader.read()
-            if raw_data is None:
-                raise EOFError
+            while parsing:  # loop until end of valid UBX/NMEA message or EOF
+                byte1 = self._read_bytes(
+                    stream, 1
+                )  # read first byte to determine protocol
+                if byte1 not in (
+                    b"\xb5",
+                    b"\x24",
+                    b"\xd3",
+                ):  # not UBX, NMEA or RTCM3, discard and continue
+                    continue
+                byte2 = self._read_bytes(stream, 1)
+                # if it's a UBX message (b'\b5\x62')
+                bytehdr = byte1 + byte2
+                if bytehdr == ubt.UBX_HDR:
+                    byten = self._read_bytes(stream, 4)
+                    clsid = byten[0:1]
+                    msgid = byten[1:2]
+                    lenb = byten[2:4]
+                    leni = int.from_bytes(lenb, "little", signed=False)
+                    byten = self._read_bytes(stream, leni + 2)
+                    plb = byten[0:leni]
+                    cksum = byten[leni : leni + 2]
+                    raw_data = bytehdr + clsid + msgid + lenb + plb + cksum
+                    parsed_data = UBXReader.parse(raw_data)
+                    parsing = False
+                # if it's an NMEA GNSS message ('$G' or '$P')
+                elif bytehdr in ubt.NMEA_HDR:
+                    byten = stream.readline()
+                    if byten[-2:] != CRLF:
+                        raise EOFError
+                    raw_data = bytehdr + byten
+                    parsed_data = NMEAReader.parse(raw_data)
+                    parsing = False
+                # if it's a RTCM3 GNSS message
+                # (byte1 = 0xd3; byte2 = 0b000000**)
+                elif byte1 == b"\xd3" and (byte2[0] & ~0x03) == 0:
+                    bytehdr3 = self._read_bytes(stream, 1)
+                    size = bytehdr3[0] | (bytehdr[1] << 8)
+                    payload = self._read_bytes(stream, size)
+                    crc = self._read_bytes(stream, 3)
+                    raw_data = bytehdr + bytehdr3 + payload + crc
+                    if USE_PYRTCM:
+                        parsed_data = RTCMReader.parse(raw_data)
+                    else:
+                        parsed_data = RTCMStub(payload)
+                    parsing = False
+                # else drop it like it's hot
+                else:
+                    parsing = False
         except EOFError:
             self.__master.event_generate("<<ubx_eof>>")
             return
@@ -358,7 +396,7 @@ class SerialHandler:
             self.__app.frm_console.update_console(bytes(str(err), "utf-8"), err)
             return
 
-        # print(f"DEBUG UBXReader._parse_data r:{raw_data} p:{parsed_data}")
+        logging.debug("raw: %s parsed: %s", raw_data, parsed_data)
         if raw_data is None or parsed_data is None:
             return
         msgprot = protocol(raw_data)
@@ -368,7 +406,13 @@ class SerialHandler:
         elif msgprot == ubt.NMEA_PROTOCOL and msgprot & protfilter:
             self.__app.frm_console.update_console(raw_data, parsed_data)
             self.__app.nmea_handler.process_data(raw_data, parsed_data)
-        elif msgprot == 0 and protfilter == 3:
+        elif msgprot == ubt.RTCM3_PROTOCOL and msgprot & protfilter:
+            self.__app.frm_console.update_console(raw_data, parsed_data)
+            # currently no handler for RTCM3 messages
+        elif (
+            msgprot == 0
+            and protfilter == ubt.NMEA_PROTOCOL | ubt.UBX_PROTOCOL | ubt.RTCM3_PROTOCOL
+        ):
             # log unknown protocol headers to console, then continue
             self.__app.frm_console.update_console(raw_data, parsed_data)
 
@@ -376,6 +420,21 @@ class SerialHandler:
         if self.__app.frm_settings.datalogging:
             self.__app.file_handler.write_logfile(raw_data, parsed_data)
 
+    def _read_bytes(self, stream: object, size: int) -> bytes:
+        """
+        Read a specified number of bytes from stream.
+
+        :param object stream: input stream
+        :param int size: number of bytes to read
+        :return: bytes
+        :raises: EOFError if stream ends prematurely
+        """
+
+        data = stream.read(size)
+        if len(data) < size:  # EOF
+            raise EOFError()
+        return data
+
     def flush(self):
         """
         Flush input buffer
