@@ -11,7 +11,7 @@ Created on 12 Sep 2020
 
 TITLE = "PyGPSClient"
 
-COPYRIGHTTXT = "\u00A9 SEMU Consulting 2020\nBSD 3 License. All Rights Reserved"
+COPYRIGHTTXT = "\u00A9 SEMU Consulting 2020\nBSD-2 License. All Rights Reserved"
 
 INTROTXT = "Welcome to PyGPSClient!"
 INTROTXTNOPORTS = (
@@ -22,7 +22,7 @@ HELPTXT = "Help..About - display About dialog."
 
 ABOUTTXT = (
     "PyGPSClient is a free, open-source NMEA & UBX GNSS/GPS client application written"
-    + " entirely in Python and tkinter.\n\n"
+    + " entirely in Python and tkinter. "
     + "Instructions and source code are available on GitHub at the link below."
 )
 
@@ -34,13 +34,12 @@ OPENFILEERROR = "ERROR! File could not be opened"
 BADJSONERROR = "ERROR! Invalid metadata file"
 NMEAVALERROR = "Value error in NMEA message: {}"
 SEROPENERROR = "Error opening serial port {}"
-NOWEBMAPERROR1 = "Map not available."
-NOWEBMAPERROR2 = "mqapikey file not found or invalid."
-NOWEBMAPERROR3 = "Unable to download web map."
-NOWEBMAPERROR4 = "Check Internet connection."
-NOWEBMAPERROR5 = "No satellite fix."
-WEBMAPHTTPERROR = "HTTP error downloading web map. Are you connected to the Internet?"
-WEBMAPERROR = "Error downloading web map"
+FILEOPENERROR = "Error opening file {}"
+NOWEBMAP = "Unable to download web map."
+NOWEBMAPKEY = NOWEBMAP + "\n\nMQAPIKEY not found or invalid."
+NOWEBMAPHTTP = NOWEBMAP + "\n\nBad HTTP response: {}.\nCheck MQAPIKEY."
+NOWEBMAPFIX = NOWEBMAP + "\n\nNo satellite fix."
+NOWEBMAPCONN = NOWEBMAP + "\n\nCheck internet connection."
 SAVETITLE = "Select Directory"
 READTITLE = "Select File"
 WAITNMEADATA = "Waiting for data..."
@@ -96,7 +95,7 @@ LBLDATALOG = "Enable DataLog"
 LBLSTREAM = "Stream\nfrom file"
 LBLTRACKRECORD = "Record GPX Track"
 LBLLEGEND = "Show Legend"
-LBLSHOWNULL = "Show Zero Signal"
+LBLSHOWUNUSED = "Show Unused Satellites"
 
 # Dialog text
 DLGUBXCONFIG = "UBX Configuration"
